# SImMER
[![Build Status](https://dev.azure.com/asavel/SImMER/_apis/build/status/arjunsavel.SImMER?branchName=master)](https://dev.azure.com/asavel/SImMER/_build?definitionId=1&_a=summary) [![codecov](https://codecov.io/gh/arjunsavel/simmer/branch/master/graph/badge.svg?token=5ERhXGwSDo)](https://codecov.io/gh/arjunsavel/simmer) [![Code Climate](https://img.shields.io/codeclimate/maintainability/arjunsavel/SImMER?style=flat)](https://codeclimate.com/github/arjunsavel/SImMER) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Build Status](https://readthedocs.org/projects/simmer/badge/?version=latest)](http://simmer.readthedocs.io/en/latest/?badge=latest) [![PyPI version](https://badge.fury.io/py/simmer.svg)](https://badge.fury.io/py/simmer)


Repository for developing the ```SImMER``` image reduction pipeline. If you'd like to help out, take a look at our [ways to contribute](https://github.com/arjunsavel/simmer/blob/master/CONTRIBUTING.md).


## Documentation
To get started, read the docs at [our readthedocs site](https://simmer.readthedocs.io/en/latest/pages/about.html).
